#!/usr/bin/env bash


__na_log_msg() {
	echo "[normalise-arch] $*" >&2;
}

normalise-arch() {

	arch="$1"; 
	if [[ -z "${arch}" ]]; then
		read -r arch;
	fi
	new_arch="${arch}";

	if [[ "${arch}" == "help" ]]; then
		__na_log_msg "normalise-arch";
		__na_log_msg "	Normalises architecture names to match the official Debian architecture names used by apt.";
		__na_log_msg "Usage:";
		__na_log_msg "	normalise-arch {architecture}";
		exit 0;
	fi

	case "${arch}" in
		"x64" )			new_arch="amd64"	;;	# Node.js tarball downloads
		"armv7" )		new_arch="armhf"	;;	# Source: Traefik
		"armv7l" )		new_arch="armhf"	;;
		"armhfv6" )		new_arch="armhf"	;;	# Source: Consul
		"armelv5" )		new_arch="armv5"	;;	# Source: Consul
		"arm" )			new_arch="armhf"	;;
		"aarch64" ) 	new_arch="arm64"	;;
		"armv8" )		new_arch="arm64"	;;
	esac

	__na_log_msg "${arch} → ${new_arch}";

	echo "${new_arch}";

}